<?php
/**
 * Record driver view helper
 *
 * PHP version 5
 *
 * Copyright (C) Villanova University 2010.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  View_Helpers
 * @author   Demian Katz <demian.katz@villanova.edu>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 */
namespace fid_bbi\View\Helper\Root;

use finc\Rewrite;
use Symfony\Component\Config\Definition\Exception\Exception;

/**
 * Record driver view helper
 *
 * @category VuFind
 * @package  View_Helpers
 * @author   Demian Katz <demian.katz@villanova.edu>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 */
class Record extends \finc\View\Helper\Root\Record
{
    /**
     * Get HTML to render a title.
     *
     * @param int $maxLength Maximum length of non-highlighted title.
     *
     * @return string
     */
    public function getTitleHtml($maxLength = 180)
    {
        $highlightedTitle = $this->driver->tryMethod('getHighlightedTitle');

        $titleRegexPattern = '/(\s[\/\.:]\s*)*$/';
        $shortTitle = preg_replace(
            $titleRegexPattern,
            '',
            trim($this->driver->tryMethod('getShortTitle'))
        );
        $title = (!empty($shortTitle) ? $shortTitle : preg_replace(
            $titleRegexPattern,
            '',
            trim($this->driver->tryMethod('getTitle'))
        ));

        if (!empty($highlightedTitle)) {
            $highlight = $this->getView()->plugin('highlight');
            $addEllipsis = $this->getView()->plugin('addEllipsis');
            return $highlight($addEllipsis($highlightedTitle, $title));
        }
        if (!empty($title)) {
            $escapeHtml = $this->getView()->plugin('escapeHtml');
            $truncate = $this->getView()->plugin('truncate');
            return $escapeHtml($truncate($title, $maxLength));
        }
        $transEsc = $this->getView()->plugin('transEsc');
        return $transEsc('Title not available');
    }

    /**
     * Get HTML to render a title.
     *
     * @param int $maxLength Maximum length of non-highlighted title.
     *
     * @return string
     */
    public function getSubTitleHtml($maxLengthArr = null)
    {
        $titleRegexPattern = '/(\s[\/\.:]\s*)*$/';
        $subTitle = preg_replace(
            $titleRegexPattern,
            '',
            trim($this->driver->tryMethod('getSubTitle'))
        );
        $sectionTitle = preg_replace(
            $titleRegexPattern,
            '',
            trim($this->driver->tryMethod('getTitleSection'))
        );
        $subtitle = (!empty($subTitle) ? ': ' . $subTitle : '') .
            (!empty($sectionTitle) ? ', ' . $sectionTitle : '');

        $subtitle = preg_replace('/^((\S*\s){'.$maxLengthArr.'})\S.*$/','$1 ...',$subtitle);

        if (!empty($subtitle)) {
            $escapeHtml = $this->getView()->plugin('escapeHtml');
            return $escapeHtml($subtitle);
        }
        return '';
    }
}
